@@ -6,7 +6,7 @@ from django.core.exceptions import ImproperlyConfigured
 TRANSLATION_FILES = tuple(getattr(settings, 'MODELTRANSLATION_TRANSLATION_FILES', ()))
 
 AVAILABLE_LANGUAGES = list(getattr(settings, 'MODELTRANSLATION_LANGUAGES',
-                                   (l[0] for l in settings.LANGUAGES)))
+                                   (val for val, label in settings.LANGUAGES)))
 DEFAULT_LANGUAGE = getattr(settings, 'MODELTRANSLATION_DEFAULT_LANGUAGE', None)
 if DEFAULT_LANGUAGE and DEFAULT_LANGUAGE not in AVAILABLE_LANGUAGES:
     raise ImproperlyConfigured('MODELTRANSLATION_DEFAULT_LANGUAGE not in LANGUAGES setting.')
@@ -54,3 +54,10 @@ for key, value in FALLBACK_LANGUAGES.items():
 ENABLE_FALLBACKS = getattr(settings, 'MODELTRANSLATION_ENABLE_FALLBACKS', True)
 
 LOADDATA_RETAIN_LOCALE = getattr(settings, 'MODELTRANSLATION_LOADDATA_RETAIN_LOCALE', True)
+
+JQUERY_URL = getattr(settings, 'JQUERY_URL',
+                     '//ajax.googleapis.com/ajax/libs/jquery/1.11.1/jquery.min.js')
+JQUERY_UI_URL = getattr(settings, 'JQUERY_UI_URL',
+                        '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.2/jquery-ui.min.js')
+JQUERY_MB_BROWSER_URL = getattr(settings, 'JQUERY_MB_BROWSER_URL',
+                                '//cdn.jsdelivr.net/jquery.mb.browser/0.1/jquery.mb.browser.min.js')
